==> org.eclipse.smartmdsd.xtext.component.componentDefinition.source_3.4.0.202011021716.jar: org/eclipse/smartmdsd/xtext/component/componentDefinition/validation/AbstractComponentDefinitionValidator.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.component.componentDefinition.validation;

import java.util.ArrayList;
import java.util.List;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.smartmdsd.xtext.service.roboticMiddleware.validation.RoboticMiddlewareValidator;
import org.eclipse.xtext.validation.ComposedChecks;
import org.eclipse.xtext.validation.NamesAreUniqueValidator;

@ComposedChecks(validators = {NamesAreUniqueValidator.class})
public abstract class AbstractComponentDefinitionValidator extends RoboticMiddlewareValidator {
	
	@Override
	protected List<EPackage> getEPackages() {
		List<EPackage> result = new ArrayList<EPackage>(super.getEPackages());
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/componentDefinition"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/seronetExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/performanceExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/coordinationExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/componentParameter"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/service/roboticMiddleware"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/base/documentation"));
		return result;
	}
}

==> org.eclipse.smartmdsd.xtext.component.componentDefinition.source_3.4.0.202204050609.jar: org/eclipse/smartmdsd/xtext/component/componentDefinition/validation/AbstractComponentDefinitionValidator.java <==
/********************************************************************************
 * Copyright (c) 2017 Technische Hochschule Ulm, Servicerobotics Ulm, Germany
 * headed by Prof. Dr. Christian Schlegel
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Alex Lotz, Dennis Stampfer, Matthias Lutz
 ********************************************************************************/
package org.eclipse.smartmdsd.xtext.component.componentDefinition.validation;

import java.util.ArrayList;
import java.util.List;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.smartmdsd.xtext.service.roboticMiddleware.validation.RoboticMiddlewareValidator;
import org.eclipse.xtext.validation.ComposedChecks;
import org.eclipse.xtext.validation.NamesAreUniqueValidator;

@ComposedChecks(validators = {NamesAreUniqueValidator.class})
public abstract class AbstractComponentDefinitionValidator extends RoboticMiddlewareValidator {
	
	@Override
	protected List<EPackage> getEPackages() {
		List<EPackage> result = new ArrayList<EPackage>(super.getEPackages());
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/componentDefinition"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/seronetExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/componentDependencyGraphExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/performanceExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/coordinationExtension"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/component/componentParameter"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/service/roboticMiddleware"));
		result.add(EPackage.Registry.INSTANCE.getEPackage("http://www.eclipse.org/smartmdsd/base/documentation"));
		return result;
	}
}
